package com.zd.airbottle.service;

import java.util.List;
import com.zd.airbottle.domain.QpFlow;
import com.zd.airbottle.domain.vo.QpFlowVO;

/**
 * 气瓶审核流程Service接口
 * 
 * @author zd
 * @date 2022-06-13
 */
public interface IQpFlowService 
{
    /**
     * 查询气瓶审核流程
     * 
     * @param id 气瓶审核流程主键
     * @return 气瓶审核流程
     */
    QpFlow selectQpFlowById(Long id);

    /**
     * 查询气瓶审核流程列表
     * 
     * @param qpFlow 气瓶审核流程
     * @return 气瓶审核流程集合
     */
    List<QpFlow> selectQpFlowList(QpFlow qpFlow);

    /**
     * 根据主键集合查询气瓶审核流程列表
     *
     * @param ids 主键集合
     * @return 气瓶审核流程集合
     */
    List<QpFlow> getListByIds(List<Long> ids);

    /**
     * 新增气瓶审核流程
     * 
     * @param qpFlow 气瓶审核流程
     * @return 结果
     */
    int insertQpFlow(QpFlowVO qpFlow);

    /**
     * 修改气瓶审核流程
     * 
     * @param qpFlow 气瓶审核流程
     * @return 结果
     */
    int updateQpFlow(QpFlow qpFlow);

    /**
     * 批量删除气瓶审核流程
     * 
     * @param ids 需要删除的气瓶审核流程主键集合
     * @return 结果
     */
    int deleteQpFlowByIds(Long[] ids);

    /**
     * 删除气瓶审核流程信息
     * 
     * @param id 气瓶审核流程主键
     * @return 结果
     */
    int deleteQpFlowById(Long id);
}
